package com.miaxis.coach.service;

import java.util.List;
import com.miaxis.coach.domain.CoachInfo;
import com.baomidou.mybatisplus.extension.service.IService;
import com.miaxis.coach.dto.CoachInfoDTO;
import com.miaxis.coach.dto.CoachInfoPcDTO;
import com.miaxis.coach.dto.CoachInfoVO;
import com.miaxis.coach.vo.CoachInfoPcVO;

/**
 * 教练Service接口
 *
 * @author wwl
 * @date 2021-01-07
 */
public interface ICoachInfoService extends IService<CoachInfo>{
    /**
     * 查询教练
     *
     * @param coachnum 教练ID
     * @return 教练
     */
    public CoachInfo selectCoachInfoById(String coachnum);

    /**
     * 查询教练列表
     *
     * @param coachInfo 教练
     * @return 教练集合
     */
    public List<CoachInfo> selectCoachInfoList(CoachInfo coachInfo);

    /**
     * 新增教练
     *
     * @param coachInfo 教练
     * @return 结果
     */
    public int insertCoachInfo(CoachInfo coachInfo);

    /**
     * 修改教练
     *
     * @param coachInfo 教练
     * @return 结果
     */
    public int updateCoachInfo(CoachInfo coachInfo);

    /**
     * 批量删除教练
     *
     * @param coachnums 需要删除的教练ID
     * @return 结果
     */
    public int deleteCoachInfoByIds(String[] coachnums);


    /**
     * 查询教练信息列表 带头像距离
     * @param coachInfoDTO
     * @return
     */
    public List<CoachInfoVO> selectCoachInfoUrlList(CoachInfoDTO coachInfoDTO);

    /**
     * pc查询教练列表
     */
    List<CoachInfoPcVO> queryList(CoachInfoPcDTO coachInfo);

    /**
     * pc教练密码重置
     * @param ids
     * @return
     */
    boolean resetPassword(Long[] ids);

    /**
     * pc删除教练（逻辑删除）
     * @param ids
     * @return
     */
    boolean removeCoach(Long[] ids);
}
